/**
 * @file        应用主入口，初始化Elysia实例
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-29
 * @description Elysia API服务应用入口文件，集成Winston日志系统和统一路由管理
 */

// Elysia
import { Elysia } from 'elysia';
// 版本信息
import * as packageJson from '@package.json';
// 路由总入口
import { controllers } from '@/modules/index'; // 使用路由总入口
// 插件总入口
import { plugins } from '@/plugins/index';
// 格式化路由
import { formatRoute } from '@/utils/formatRoute';

/**
 * 自定义认证错误类
 * @description 用于处理认证相关的错误
 */
class AuthenticationError extends Error {
    constructor(message: string, code = 500) {
        super(message);
        this.name = 'AuthenticationError';
        if (code === 401) {
            this.name = 'Unauthorized';
        }
    }
}

/**
 * Elysia应用实例
 * @description 主应用实例，集成所有插件和路由
 */
export const app = new Elysia({ name: 'main-app' })
    // 环境变量
    .decorate('env', process.env.NODE_ENV || process.env.BUN_ENV || 'development')
    // 版本信息
    .state({
        version: packageJson.version,
    })
    // 使用插件
    .use(plugins)

    // 使用统一的路由入口 所有业务的入口文件
    .use(controllers)

    .onStart(() => {
        console.log('🚀 Elysia 服务启动成功');
        console.log(formatRoute(app.routes));
        console.log('📝 API 文档地址: http://localhost:3000/docs');
        console.log('🏥 健康检查: http://localhost:3000/api/health');
        console.log('📡 API 版本信息: http://localhost:3000/api/version');
    })
    .onStop(() => {
        console.log('👋 Elysia 服务正在关闭...');
    });
