/**
 * @file        样例接口响应Schema定义
 * @author      hotok
 * @date        2025-06-29
 * @lastEditor  hotok
 * @lastEditTime 2025-06-29
 * @description 样例接口的响应结构定义，基于全局响应格式扩展
 * 
 * ⚠️  响应格式管理规范：
 * 1. 当前文件只定义成功响应(200)的具体数据结构
 * 2. 错误响应(400, 401, 422, 500等)统一使用 @/validators/global.response.ts 中的 CommonResponses
 * 3. 这样可以保证错误响应格式的一致性，便于前端统一处理
 * 4. 如需自定义错误响应，请在 CommonResponses 中添加，而不是在具体业务文件中定义
 */

import { t } from 'elysia';
import { UserInfoSchema } from './example.schema';
import { CommonResponses } from '@/validators/global.response';

/**
 * 根据用户名查询用户成功响应
 * @description 定义成功查询用户时返回的数据结构
 */
export const GetUserByUsernameSuccessResponse = t.Object({
    code: t.Literal(0, {
        description: '成功响应码',
    }),
    message: t.String({
        description: '成功消息',
        examples: ['查询用户成功'],
    }),
    data: UserInfoSchema,
});

/**
 * 根据用户名查询用户接口的所有可能响应
 * @description 组合成功响应和公共错误响应，确保格式一致性
 */
export const GetUserByUsernameResponses = {
    /** 200 查询成功 - 使用自定义成功响应 */
    200: GetUserByUsernameSuccessResponse,
    
    /** 400 业务错误 - 使用全局公共错误响应 */
    400: CommonResponses[400],
    
    /** 401 认证失败 - 使用全局公共错误响应 */
    401: CommonResponses[401],
    
    /** 422 参数验证失败 - 使用全局公共错误响应 */
    422: CommonResponses[422],
    
    /** 500 服务器内部错误 - 使用全局公共错误响应 */
    500: CommonResponses[500],
}; 