/**
 * @file        JWT插件封装
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-29
 * @description 封装Elysia JWT插件，统一配置密钥，提供类型安全的JWT认证
 */
import { Elysia } from 'elysia';
import { jwt } from '@elysiajs/jwt';
import { jwtConfig } from '@/config/jwt.config';
import type { JwtUserType, JwtPayloadType } from '@/type/jwt.type';

export const jwtPlugin = jwt({
    name: 'jwt',
    secret: jwtConfig.secret,
    exp: jwtConfig.exp,
});

export const jwtAuthPlugin = (app: Elysia) =>
    app
        .use(jwtPlugin)
        .derive(async ({ jwt, headers, status }) => {
            const authHeader = headers['authorization'];
            if (!authHeader?.startsWith('Bearer ')) {
                return status(401, '未携带Token');
            }
            const token = authHeader.replace('Bearer ', '');
            try {
                const payload = await jwt.verify(token) as JwtPayloadType | false;
                if (!payload) return status(401, 'Token无效');
                
                // 提取用户信息
                const user: JwtUserType = {
                    userId: payload.userId,
                    username: payload.username,
                    email: payload.email,
                    nickname: payload.nickname,
                    status: payload.status,
                    role: payload.role,
                };
                
                return { user } as const;
            } catch {
                return status(401, 'Token无效');
            }
        })
        .onBeforeHandle(({ user, status }) => {
            if (!user) {
                return status(401, '未授权');
            }
        });
