/**
 * @file        响应格式工具函数
 * @author      AI助手
 * @date        2025-06-29
 * @description 提供统一的响应格式构造函数，确保API响应格式的一致性
 */

import type { ErrorCode } from '@/constants/error-codes';
import { ERROR_CODES, ERROR_CODE_MESSAGES } from '@/constants/error-codes';

/**
 * 标准API响应格式
 */
export interface ApiResponse<T = any> {
    /** 业务状态码 */
    code: ErrorCode;
    /** 响应消息 */
    message: string;
    /** 响应数据 */
    data: T;
    /** 时间戳 */
    timestamp?: string;
    /** 请求ID（可选，用于追踪） */
    requestId?: string;
}

/**
 * 成功响应构造函数
 * @param data 响应数据
 * @param message 自定义消息，默认使用标准成功消息
 * @returns 标准成功响应格式
 */
export function successResponse<T>(
    data: T,
    message: string = ERROR_CODE_MESSAGES[ERROR_CODES.SUCCESS]
): ApiResponse<T> {
    return {
        code: ERROR_CODES.SUCCESS,
        message,
        data,
        timestamp: new Date().toISOString(),
    };
}

/**
 * 错误响应构造函数
 * @param code 错误码
 * @param message 错误消息，如果不提供则使用默认消息
 * @param data 错误详情数据，默认为null
 * @returns 标准错误响应格式
 */
export function errorResponse<T = null>(
    code: ErrorCode,
    message?: string,
    data: T = null as T
): ApiResponse<T> {
    return {
        code,
        message: message || ERROR_CODE_MESSAGES[code] || '未知错误',
        data,
        timestamp: new Date().toISOString(),
    };
}

/**
 * 分页数据响应格式
 */
export interface PaginatedData<T> {
    /** 数据列表 */
    items: T[];
    /** 总记录数 */
    total: number;
    /** 当前页码 */
    page: number;
    /** 每页记录数 */
    pageSize: number;
    /** 总页数 */
    totalPages: number;
    /** 是否有下一页 */
    hasNext: boolean;
    /** 是否有上一页 */
    hasPrev: boolean;
}

/**
 * 分页响应构造函数
 * @param items 数据列表
 * @param total 总记录数
 * @param page 当前页码
 * @param pageSize 每页记录数
 * @param message 自定义消息
 * @returns 标准分页响应格式
 */
export function paginatedResponse<T>(
    items: T[],
    total: number,
    page: number,
    pageSize: number,
    message: string = '查询成功'
): ApiResponse<PaginatedData<T>> {
    const totalPages = Math.ceil(total / pageSize);
    
    return successResponse<PaginatedData<T>>({
        items,
        total,
        page,
        pageSize,
        totalPages,
        hasNext: page < totalPages,
        hasPrev: page > 1,
    }, message);
}

/**
 * 业务错误类
 * @description 用于抛出具有特定错误码的业务异常
 */
export class BusinessError extends Error {
    public readonly code: ErrorCode;

    constructor(message: string, code: ErrorCode = ERROR_CODES.BUSINESS_ERROR) {
        super(message);
        this.name = 'BusinessError';
        this.code = code;
    }
}

/**
 * 验证错误类
 * @description 用于参数验证失败的场景
 */
export class ValidationError extends BusinessError {
    constructor(message: string) {
        super(message, ERROR_CODES.VALIDATION_ERROR);
        this.name = 'ValidationError';
    }
}

/**
 * 认证错误类
 * @description 用于认证相关的错误
 */
export class AuthenticationError extends BusinessError {
    constructor(message: string, code: ErrorCode = ERROR_CODES.UNAUTHORIZED) {
        super(message, code);
        this.name = 'AuthenticationError';
    }
}

/**
 * 权限错误类
 * @description 用于权限不足的场景
 */
export class ForbiddenError extends BusinessError {
    constructor(message: string = '权限不足') {
        super(message, ERROR_CODES.FORBIDDEN);
        this.name = 'ForbiddenError';
    }
}

/**
 * 资源不存在错误类
 * @description 用于资源不存在的场景
 */
export class NotFoundError extends BusinessError {
    constructor(message: string = '资源不存在') {
        super(message, ERROR_CODES.NOT_FOUND);
        this.name = 'NotFoundError';
    }
} 