/**
 * @file        文本格式化工具类
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 提供字符串居中、对齐、截断等格式化功能
 */

/**
 * 字符串居中对齐并限制长度
 * @param text 要处理的文本
 * @param width 总宽度
 * @param fillChar 填充字符（默认为空格）
 * @returns 居中对齐的字符串
 */
export const centerText = (text: string, width: number, fillChar: string = ' '): string => {
    // 如果文本长度大于等于指定宽度，截断文本
    if (text.length >= width) {
        return text.slice(0, width);
    }

    // 计算左右需要填充的空格数
    const totalPadding = width - text.length;
    const leftPadding = Math.floor(totalPadding / 2);
    const rightPadding = totalPadding - leftPadding;

    return fillChar.repeat(leftPadding) + text + fillChar.repeat(rightPadding);
};

/**
 * 字符串左对齐并限制长度
 * @param text 要处理的文本
 * @param width 总宽度
 * @param fillChar 填充字符（默认为空格）
 * @returns 左对齐的字符串
 */
export const leftPad = (text: string, width: number, fillChar: string = ' '): string => {
    if (text.length >= width) {
        return text.slice(0, width);
    }
    return text + fillChar.repeat(width - text.length);
};

/**
 * 字符串右对齐并限制长度
 * @param text 要处理的文本
 * @param width 总宽度
 * @param fillChar 填充字符（默认为空格）
 * @returns 右对齐的字符串
 */
export const rightPad = (text: string, width: number, fillChar: string = ' '): string => {
    if (text.length >= width) {
        return text.slice(0, width);
    }
    return fillChar.repeat(width - text.length) + text;
};

/**
 * 截断文本并添加省略号
 * @param text 要处理的文本
 * @param maxLength 最大长度
 * @param ellipsis 省略号（默认为...）
 * @returns 截断后的字符串
 */
export const truncateText = (text: string, maxLength: number, ellipsis: string = '...'): string => {
    if (text.length <= maxLength) {
        return text;
    }
    return text.slice(0, maxLength - ellipsis.length) + ellipsis;
};

// // 测试示例
// console.log('=== 字符串格式化测试 ===');
// console.log(`"${centerText('居中居中居中居中居中居中居中', 10)}"`);           // "   居中   "
// console.log(`"${centerText('很长的文本内容', 10)}"`);    // "很长的文本内容"
// console.log(`"${leftPad('左对齐', 10)}"`);            // "左对齐    "
// console.log(`"${rightPad('右对齐', 10)}"`);           // "    右对齐"
// console.log(`"${truncateText('这是一个很长的文本', 8)}"`); // "这是一个很..."
