/**
 * @file        全局响应Schema定义
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 定义全局通用的响应结构、错误码说明，供Swagger文档和接口验证使用
 */

import { t } from 'elysia';

/**
 * 全局错误码定义
 * @description 系统错误码说明，便于前端开发和API文档查阅
 */
export const ERROR_CODES = {
    /** 成功 */
    SUCCESS: 0,
    /** 通用业务错误 */
    BUSINESS_ERROR: 400,
    /** 认证失败 */
    UNAUTHORIZED: 401,
    /** 权限不足 */
    FORBIDDEN: 403,
    /** 资源未找到 */
    NOT_FOUND: 404,
    /** 参数验证失败 */
    VALIDATION_ERROR: 422,
    /** 服务器内部错误 */
    INTERNAL_ERROR: 500,
    /** 服务不可用 */
    SERVICE_UNAVAILABLE: 503,
} as const;

/**
 * 错误码说明映射
 */
export const ERROR_CODE_DESCRIPTIONS = {
    [ERROR_CODES.SUCCESS]: '操作成功',
    [ERROR_CODES.BUSINESS_ERROR]: '业务逻辑错误',
    [ERROR_CODES.UNAUTHORIZED]: '身份认证失败，请重新登录',
    [ERROR_CODES.FORBIDDEN]: '权限不足，无法访问该资源',
    [ERROR_CODES.NOT_FOUND]: '请求的资源不存在',
    [ERROR_CODES.VALIDATION_ERROR]: '请求参数验证失败',
    [ERROR_CODES.INTERNAL_ERROR]: '服务器内部错误，请稍后重试',
    [ERROR_CODES.SERVICE_UNAVAILABLE]: '服务暂时不可用，请稍后重试',
} as const;

/**
 * 基础响应结构Schema
 */
export const BaseResponseSchema = t.Object({
    /** 响应码：0表示成功，其他表示错误 */
    code: t.Number({
        description: '响应码，0表示成功，其他表示错误',
        examples: [0, 400, 401, 403, 404, 422, 500, 503],
    }),
    /** 响应消息 */
    message: t.String({
        description: '响应消息，描述操作结果',
        examples: ['操作成功', '参数验证失败', '权限不足'],
    }),
    /** 响应数据 */
    data: t.Any({
        description: '响应数据，成功时包含具体数据，失败时通常为null',
    }),
});

/**
 * 成功响应Schema
 */
export const SuccessResponseSchema = t.Object({
    code: t.Literal(0, {
        description: '成功响应码',
    }),
    message: t.String({
        description: '成功消息',
        examples: ['操作成功', '获取数据成功', '创建成功'],
    }),
    data: t.Any({
        description: '成功时返回的数据',
    }),
});

/**
 * 错误响应Schema
 */
export const ErrorResponseSchema = t.Object({
    code: t.Number({
        description: '错误响应码',
        examples: [400, 401, 403, 404, 422, 500, 503],
    }),
    message: t.String({
        description: '错误消息',
        examples: ['参数验证失败', '认证失败', '权限不足', '资源不存在', '服务器内部错误'],
    }),
    data: t.Null({
        description: '错误时数据字段为null',
    }),
});

/**
 * 分页响应Schema
 */
export const PaginationResponseSchema = t.Object({
    code: t.Literal(0),
    message: t.String(),
    data: t.Object({
        /** 分页数据列表 */
        list: t.Array(t.Any(), {
            description: '数据列表',
        }),
        /** 分页信息 */
        pagination: t.Object({
            /** 当前页码 */
            page: t.Number({
                description: '当前页码，从1开始',
                minimum: 1,
                examples: [1, 2, 3],
            }),
            /** 每页条数 */
            pageSize: t.Number({
                description: '每页条数',
                minimum: 1,
                maximum: 100,
                examples: [10, 20, 50],
            }),
            /** 总条数 */
            total: t.Number({
                description: '总条数',
                minimum: 0,
                examples: [0, 100, 1500],
            }),
            /** 总页数 */
            totalPages: t.Number({
                description: '总页数',
                minimum: 0,
                examples: [0, 5, 75],
            }),
            /** 是否有下一页 */
            hasNext: t.Boolean({
                description: '是否有下一页',
            }),
            /** 是否有上一页 */
            hasPrev: t.Boolean({
                description: '是否有上一页',
            }),
        }),
    }),
});

/**
 * 常用HTTP状态码响应模板
 */
export const CommonResponses = {
    /** 200 成功 */
    200: SuccessResponseSchema,
    /** 400 业务错误 */
    400: ErrorResponseSchema,
    /** 401 认证失败 */
    401: t.Object({
        code: t.Literal(401),
        message: t.String({
            examples: ['身份认证失败，请重新登录', 'Token已过期', 'Token格式错误'],
        }),
        data: t.Null(),
    }),
    /** 403 权限不足 */
    403: t.Object({
        code: t.Literal(403),
        message: t.String({
            examples: ['权限不足，无法访问该资源', '用户角色权限不够'],
        }),
        data: t.Null(),
    }),
    /** 404 资源未找到 */
    404: t.Object({
        code: t.Literal(404),
        message: t.String({
            examples: ['请求的资源不存在', '用户不存在', '文件未找到'],
        }),
        data: t.Null(),
    }),
    /** 422 参数验证失败 */
    422: t.Object({
        code: t.Literal(422),
        message: t.String({
            examples: ['请求参数验证失败', '邮箱格式不正确', '密码长度不符合要求'],
        }),
        data: t.Null(),
    }),
    /** 500 服务器内部错误 */
    500: t.Object({
        code: t.Literal(500),
        message: t.String({
            examples: ['服务器内部错误，请稍后重试', '数据库连接失败', '系统异常'],
        }),
        data: t.Null(),
    }),
    /** 503 服务不可用 */
    503: t.Object({
        code: t.Literal(503),
        message: t.String({
            examples: ['服务暂时不可用，请稍后重试', '系统维护中', '依赖服务异常'],
        }),
        data: t.Null(),
    }),
};

/**
 * 健康检查响应Schema
 */
export const HealthCheckResponseSchema = t.Object({
    code: t.Number(),
    message: t.String(),
    data: t.Object({
        status: t.Union([
            t.Literal('healthy'),
            t.Literal('unhealthy'),
            t.Literal('degraded'),
        ], {
            description: '系统健康状态：healthy-健康，unhealthy-不健康，degraded-降级',
        }),
        timestamp: t.String({
            description: 'ISO时间戳',
            examples: ['2024-06-28T12:00:00.000Z'],
        }),
        uptime: t.Number({
            description: '系统运行时间（秒）',
            examples: [3600, 86400],
        }),
        responseTime: t.Number({
            description: '响应时间（毫秒）',
            examples: [15, 50, 100],
        }),
        version: t.String({
            description: '系统版本',
            examples: ['1.0.0', '1.2.3'],
        }),
        environment: t.String({
            description: '运行环境',
            examples: ['development', 'production', 'test'],
        }),
        components: t.Object({
            mysql: t.Optional(t.Object({
                status: t.String(),
                responseTime: t.Optional(t.Number()),
                error: t.Optional(t.String()),
                details: t.Optional(t.Any()),
            })),
            redis: t.Optional(t.Object({
                status: t.String(),
                responseTime: t.Optional(t.Number()),
                error: t.Optional(t.String()),
                details: t.Optional(t.Any()),
            })),
        }),
    }),
}); 